"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.tmtc.model import (  # noqa
    Acknowledgment,
    Alarm,
    AlarmRangeSet,
    AlarmUpdate,
    Calibrator,
    CommandHistory,
    ContainerData,
    EventAlarm,
    IssuedCommand,
    MonitoredCommand,
    Packet,
    ParameterAlarm,
    ParameterData,
    ParameterValue,
    ValueUpdate,
    VerificationConfig,
)

RangeSet = AlarmRangeSet
"""
Temporary backwards compatibility.
Prefer to use the class 'AlarmRangeSet'.
"""



"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.archive.model import (  # noqa
    ColumnData,
    IndexGroup,
    IndexRecord,
    ParameterRange,
    ParameterRangeEntry,
    ResultSet,
    Sample,
    Stream,
    StreamData,
    Table,
)



"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.tmtc.client import (  # noqa
    AlarmSubscription,
    CommandConnection,
    CommandHistorySubscription,
    ContainerSubscription,
    ParameterSubscription,
    ProcessorClient,
)



"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.model import (  # noqa
    AuthInfo,
    Event,
    Instance,
    InstanceTemplate,
    Link,
    LinkAction,
    LoadParameterValuesResult,
    ObjectPrivilege,
    Processor,
    RdbTablespace,
    ServerInfo,
    Service,
    UserInfo,
)



"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.core.exceptions import (  # noqa
    ConnectionFailure,
    NotFound,
    TimeoutError,
    Unauthorized,
    YamcsError,
)



"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.timeline.model import (  # noqa
    Band,
    CommandBand,
    Item,
    ItemBand,
    Spacer,
    TimeRuler,
    View,
)



"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.filetransfer.model import (  # noqa
    EntityInfo,
    FileTransferCapabilities,
    FileTransferOption,
    FileTransferService,
    RemoteFile,
    RemoteFileListing,
    Transfer,
)

Service = FileTransferService
"""
Temporary backwards compatibility.
Prefer to use the class 'FileTransferService'.
"""



"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.core.helpers import (  # noqa
    FixedDelay,
    ProtoList,
    adapt_name_for_rest,
    delimit_protobuf,
    do_get,
    do_post,
    do_request,
    parse_server_time,
    parse_server_timestring,
    parse_value,
    split_protobuf_stream,
    to_argument_value,
    to_isostring,
    to_named_object_id,
    to_named_object_ids,
    to_server_time,
)



"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.filetransfer.model import (  # noqa
    FileListSubscription,
    FileTransferClient,
    FileTransferServiceClient,
    TransferSubscription,
)

ServiceClient = FileTransferServiceClient
"""
Temporary backwards compatibility.
Prefer to use the class 'FileTransferServiceService'.
"""
